Installation — Ryser 0.0.10 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Ryser 0.0.10 documentation »

# Installation

## Requirements

Ryser needs:

- NetworkX (http://networkx.github.io/)
- Vizing (http://pythonhosted.org/vizing/)

## Download

The latest Ryser distribution can be downloaded from PyPi (https://pypi.python.org/pypi/ryser/)

## Installation Instructions

The recommended way to install Ryser is with pip (http://www.pip-installer.org/en/latest/)

    $ pip install ryser

### Navigation

- index
- modules |
- next |
- previous |
- Ryser 0.0.10 documentation »